Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AutoscalingV1alpha1Client ¶
type AutoscalingV1alpha1Client struct {
// contains filtered or unexported fields
}
AutoscalingV1alpha1Client is used to interact with features provided by the autoscaling.internal.knative.dev group.
func New ¶
func New(c rest.Interface) *AutoscalingV1alpha1Client
New creates a new AutoscalingV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AutoscalingV1alpha1Client, error)
NewForConfig creates a new AutoscalingV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AutoscalingV1alpha1Client
NewForConfigOrDie creates a new AutoscalingV1alpha1Client for the given config and panics if there is an error in the config.
func (*AutoscalingV1alpha1Client) Metrics ¶ added in v0.8.0
func (c *AutoscalingV1alpha1Client) Metrics(namespace string) MetricInterface
func (*AutoscalingV1alpha1Client) PodAutoscalers ¶
func (c *AutoscalingV1alpha1Client) PodAutoscalers(namespace string) PodAutoscalerInterface
func (*AutoscalingV1alpha1Client) RESTClient ¶
func (c *AutoscalingV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type AutoscalingV1alpha1Interface ¶
type AutoscalingV1alpha1Interface interface {
RESTClient() rest.Interface
MetricsGetter
PodAutoscalersGetter
}
type MetricExpansion ¶ added in v0.8.0
type MetricExpansion interface{}
type MetricInterface ¶ added in v0.8.0
type MetricInterface interface {
Create(*v1alpha1.Metric) (*v1alpha1.Metric, error)
Update(*v1alpha1.Metric) (*v1alpha1.Metric, error)
UpdateStatus(*v1alpha1.Metric) (*v1alpha1.Metric, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Metric, error)
List(opts v1.ListOptions) (*v1alpha1.MetricList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Metric, err error)
MetricExpansion
}
MetricInterface has methods to work with Metric resources.
type MetricsGetter ¶ added in v0.8.0
type MetricsGetter interface {
Metrics(namespace string) MetricInterface
}
MetricsGetter has a method to return a MetricInterface. A group's client should implement this interface.
type PodAutoscalerExpansion ¶
type PodAutoscalerExpansion interface{}
type PodAutoscalerInterface ¶
type PodAutoscalerInterface interface {
Create(*v1alpha1.PodAutoscaler) (*v1alpha1.PodAutoscaler, error)
Update(*v1alpha1.PodAutoscaler) (*v1alpha1.PodAutoscaler, error)
UpdateStatus(*v1alpha1.PodAutoscaler) (*v1alpha1.PodAutoscaler, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.PodAutoscaler, error)
List(opts v1.ListOptions) (*v1alpha1.PodAutoscalerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.PodAutoscaler, err error)
PodAutoscalerExpansion
}
PodAutoscalerInterface has methods to work with PodAutoscaler resources.
type PodAutoscalersGetter ¶
type PodAutoscalersGetter interface {
PodAutoscalers(namespace string) PodAutoscalerInterface
}
PodAutoscalersGetter has a method to return a PodAutoscalerInterface. A group's client should implement this interface.